#!/bin/bash
#
#PBS -j oe
#PBS -N dmabn.rimp2.pvdz
#PBS -M jmewes@iwr.uni-heidelberg.de
#PBS -m ea

#PBS -l nodes=1:ppn=4,walltime=6:00:00,mem=10G,vmem=12G
#PBS -N dmabn.rimp2.pvdz

module add intel/compiler/64/15.0/2015.0.090
module add intel/ipp/64/8.2/2015.0.090
module add intel/mkl/64/11.2/2015.0.090
module add intel/tbb/64/4.3/2015.0.090
module add openmpi/intel/1.6.5
module list

STATUS=0
RUNDIR="/lscratch/$PBS_JOBID"
STARTDIR="/export/home/jmewes/CALC/EQSOLV_CT_MOLs/DMABN/OPT"
SOURCEDIR="/export/home/jmewes/CALC/EQSOLV_CT_MOLs/DMABN/OPT"

INPUT="dmabn.rimp2.pvdz.in"
OUTPUT="dmabn.rimp2.pvdz.out"
SAVEDIR=""

# use max number of nodes ...
# checking how many nodes are available
NP=`cat $PBS_NODEFILE | wc -l`
cat $PBS_NODEFILE


if [ -z $NP ]; then
   NP=1
fi

if [ -z "$ORCATMP" ]; then 
   ORCATMP=$TMPDIR
fi

# preparing the location for execution of orca
test -d $RUNDIR || mkdir -p $RUNDIR

# collect all necessary files and copy them to the  directory

cp $SOURCEDIR/$INPUT $ORCATMP/
cp $SOURCEDIR/*.gbw $RUNDIR
cp $SOURCEDIR/*.hess $RUNDIR
cp $SOURCEDIR/$INPUT $RUNDIR/


touch $STARTDIR/$OUTPUT.temp
cd $ORCATMP
sleep 0.1 && tail -n1000 -f "$OUTPUT" > $STARTDIR/$OUTPUT.temp &
# timestamp and orca start
echo "Job $PBS_JOBNAME is started at `date`"
echo "Job is executed in $TMPDIR on $NP nodes:"
cat $PBS_NODEFILE

/opt/software/Orca/3.0.1/orca  $INPUT > $OUTPUT $SAVEDIR 
STATUS=$?


# job ended ...
echo "Job $PBS_JOBNAME ended at `date`."

#
# clean up directory
#

# move output to run directory
if [ -e "$OUTPUT" ]; then
   cp "$OUTPUT" "$RUNDIR"
   rm *.tmp*
   cp * "$STARTDIR"

# move output to start directory
cd $RUNDIR
   cp "$OUTPUT" "$STARTDIR"
   rm -f $OUTPUT.temp
   
   if [ $STATUS -eq 0 ]; then
      # check if job terminated successfully
      if [ `grep -c "****ORCA TERMINATED NORMALLY****" $OUTPUT` -eq 1 ]; then
         echo "Job terminated successfully."
         STATUS=0
      else
         echo "Job aborted."
         STATUS=1
      fi
   fi
   


else
   echo "Job aborted."
   STATUS=2
fi

sync

exit $STATUS

